==> haskell-mwc-random-0.13.5.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.5.0
id: mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
key: mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
abi: 09f6d48f76f112685f3d5ff68b75e27a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.5.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/mwc-random-0.13.5.0
hs-libraries: HSmwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
depends:
    base-4.9.0.0 primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa time-1.6.0.1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.13.5.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.5.0
id: mwc-random-0.13.5.0-JV0Fije0tjpAZxTL84rKQ4
key: mwc-random-0.13.5.0-JV0Fije0tjpAZxTL84rKQ4
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
abi: 9d6c03ecac06c0768c17e7983bf1ee69
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.5.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/mwc-random-0.13.5.0
hs-libraries: HSmwc-random-0.13.5.0-JV0Fije0tjpAZxTL84rKQ4
depends:
    base-4.9.0.0 primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ time-1.6.0.1
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
